elephant.test.test_spike_train_surrogates module — Elephant 0.5.0 documentation

# elephant.test.test_spike_train_surrogates module

unittests for spike_train_surrogates module.

class `elephant.test.test_spike_train_surrogates.` `SurrogatesTestCase`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Methods

  `test_dither_spike_train_empty_train`()
  `test_dither_spike_train_false_edges`()
  `test_dither_spike_train_output_decimals`()
  `test_dither_spike_train_output_format`()
  `test_dither_spikes_empty_train`()
  `test_dither_spikes_false_edges`()
  `test_dither_spikes_output_decimals`()
  `test_dither_spikes_output_format`()
  `test_jitter_spikes_empty_train`()
  `test_jitter_spikes_output_format`()
  `test_jitter_spikes_same_bins`()
  `test_jitter_spikes_unequal_binsize`()
  `test_randomise_spikes_empty_train`()
  `test_randomise_spikes_output_decimals`()
  `test_randomise_spikes_output_format`()
  `test_shuffle_isis_empty_train`()
  `test_shuffle_isis_output_decimals`()
  `test_shuffle_isis_output_format`()
  `test_shuffle_isis_same_isis`()
  `test_surr_method`()

`elephant.test.test_spike_train_surrogates.` `suite`()